use std::ffi::{CString, NulError};

use x11::xlib;



pub struct Display {
    window: u64,
    display: *mut xlib::Display

}

impl Display {
    pub fn new() -> Result<Self, ()> {
        let (window, display) = unsafe { 
            let display = xlib::XOpenDisplay(std::ptr::null());
            
            if display.is_null() {
                eprintln!("ERROR: Could not open x11 display");
                return Err(());
            }

            (
                xlib::XDefaultRootWindow(display),
                display
            )
        };

        Ok(Self {
            window,
            display
        })
    }
    
    pub fn write_display_name(&mut self, name: &str) -> Result<(), NulError> {
        let cstr = CString::new(name)?;
        unsafe {
            xlib::XStoreName(self.display, self.window, cstr.as_ptr() as *const i8);
            xlib::XFlush(self.display);
        }

        Ok(())
    }
}
